@@ -1,44 +1,41 @@
 from typing import List, Tuple
 import json
 import re
-from nonebot import on_command
 import requests
 import os
 from nonebot import get_bot
 from nonebot.log import logger
-from nonebot.adapters.onebot.v11 import Message
+from os.path import abspath, dirname
+
+PackagePath =  dirname(abspath(__file__))
 
 __PLUGIN_NAME = "[B站整合~基础]"
 
 async def createUserFile(userFile: str, nickName: str, streamers: List[str]=[], ups: List[str]=[], telegrams: List[str]=[]):
-    """
-    @description  :
-    创建用户文件，包含用户名，关注的主播，关注的up主以及关注的节目
-    ---------
-    @param  :
-    userFile: 创建的文件名
-    nickName: 用户名
-    streamers: 关注的主播列表s
-    ups: 关注的up主列表
-    telegrams: 关注的节目列表
-    -------
-    @Returns  :
-    无返回值
-    -------
-    """
+    '''创建用户/群文件
+
+    Args:
+        userFile (str): 文件路径
+        nickName (str): 用户名/群名
+        streamers (List[str], optional): 关注的主播. Defaults to [].
+        ups (List[str], optional): 关注的up主. Defaults to [].
+        telegrams (List[str], optional): 关注的番剧. Defaults to [].
+    '''
     
-    with open(userFile, 'w+') as f:
+    with open(userFile, 'w+', encoding='utf-8') as f:
+            logger.debug(f'{__PLUGIN_NAME}群名为{nickName}')
+            
             userInfo = [nickName, streamers, ups, telegrams]
-            json.dump(userInfo, f)
+            json.dump(userInfo, f, ensure_ascii=False)
     logger.debug(f'{__PLUGIN_NAME}用户文件{userFile}创建成功')
 
 async def FollowModifyUserFile(userFile: str, successList: List[str], type: int):
     """
     @description  :
-    根据用户的关注操作，修改用户文件
+    根据用户的关注操作，修改用户/群文件
     ---------
     @param  :
-    userFile:       用户的文件名
+    userFile:       用户/群的文件名
     successList:    成功关注的列表
     type:           1 - 主播, 2 - up主, 3 - 节目
     -------
@@ -46,15 +43,14 @@ async def FollowModifyUserFile(userFile: str, successList: List[str], type: int)
     无返回值
     -------
     """
-    logger.debug(f'{__PLUGIN_NAME}正在打开用户文件{userFile}')
-    with open(userFile, "r+") as f:
+    with open(userFile, "r+", encoding='utf-8') as f:
         userInfo = json.load(f)
         userInfo[type] += successList
         # [nickname, [streamer], [up], [telegrams]]
         f.seek(0)
         f.truncate()
-        json.dump(userInfo, f)
-        logger.debug(f'{__PLUGIN_NAME}用户文件更新成功')
+        json.dump(userInfo, f, ensure_ascii=False)
+        logger.debug(f'{__PLUGIN_NAME}用户{userInfo[0]}文件更新成功')
 
 async def UnfollowModifyUserFile(userFile: str, successList: List[str], type: int):
     """
@@ -70,15 +66,13 @@ async def UnfollowModifyUserFile(userFile: str, successList: List[str], type: in
     无返回值
     -------
     """
-    logger.debug(f'{__PLUGIN_NAME}正在打开用户文件{userFile}')
-    with open(userFile, "r+") as f:
+    with open(userFile, "r+", encoding='utf-8') as f:
         userInfo = json.load(f)
         userInfo[type] = list(set(userInfo[type]) - set(successList))
             # [nickname, [streamer], [up], [telegrams]]
         f.seek(0)
         f.truncate()
-        json.dump(userInfo, f)
-        logger.debug(f'{__PLUGIN_NAME}用户文件更新成功, type = {type}')
+        json.dump(userInfo, f, ensure_ascii=False)
 
 def parseB23Url(url: str) -> Tuple[bool, int, str]:
     """
@@ -93,10 +87,7 @@ def parseB23Url(url: str) -> Tuple[bool, int, str]:
     [isSuccess, type, id]
     type: 1-直播房间号;2-up主uid;3-节目的epid
     -------
-    """
-    
-    logger.debug(f'{__PLUGIN_NAME}对短链接{url}进行转换')
-    
+    """ 
     API = 'https://duanwangzhihuanyuan.bmcx.com/web_system/bmcx_com_www/system/file/duanwangzhihuanyuan/get/?ajaxtimestamp=1646565831920'
     payload = {'turl': url}
     res = requests.post(url=API, data=payload)
@@ -133,7 +124,27 @@ def GetAllUser() -> List[str]:
     -------
     """
     
-    users = os.listdir('./src/plugins/nonebot_plugin_bilibilibot/file/user')
+    users = os.listdir(f'{PackagePath}/file/user')
+    result = []
+    for user in users:
+        userID = user.split('.')[0]
+        result.append(userID)
+    return result
+
+def GetAllGroup() -> List[str]:
+    """
+    @description  :
+    获取所有群
+    ---------
+    @param  :
+    无
+    -------
+    @Returns  :
+    返回所有群号组成的列表
+    -------
+    """
+    
+    users = os.listdir(f'{PackagePath}/file/group')
     result = []
     for user in users:
         userID = user.split('.')[0]
@@ -157,6 +168,18 @@ async def SendMsgToUsers(msg: str, users: List[str]):
     bot = get_bot()
     for user in users:
         await bot.send_msg(message=msg, user_id = user)
+    
+async def SendMsgToGroups(msg: str, groups: List[str]):
+    '''向所有群组发送公告
+
+    Args:
+        msg (str): 公告内容
+        groups (List[str]): 群组列表
+    '''
+    
+    bot = get_bot()
+    for group in groups:
+        await bot.send_msg(message=msg, group_id = group)
 
 def CheckDir():
     """
@@ -170,35 +193,30 @@ def CheckDir():
     
     -------
     """
-    logger.debug(f'{__PLUGIN_NAME}检测相关文件目录是否存在')
-    baseDir = './src/plugins/nonebot_plugin_bilibilibot/file/'
+    
+    baseDir = f'{PackagePath}/file/'
 
     if not os.path.exists(baseDir + 'source'):
         logger.debug(f'{__PLUGIN_NAME}source文件夹不存在')
         os.makedirs(baseDir + 'source')
-    else:
-        logger.debug(f'{__PLUGIN_NAME}source文件夹存在')
         
     if not os.path.exists(baseDir + 'stream'):
         logger.debug(f'{__PLUGIN_NAME}stream文件夹不存在')
         os.makedirs(baseDir + 'stream')
-    else:
-        logger.debug(f'{__PLUGIN_NAME}stream文件夹存在')
-        
+    
     if not os.path.exists(baseDir + 'telegram'):
         logger.debug(f'{__PLUGIN_NAME}telegram文件夹不存在')
         os.makedirs(baseDir + 'telegram')
-    else:
-        logger.debug(f'{__PLUGIN_NAME}telegram文件夹存在')
-        
+    
     if not os.path.exists(baseDir + 'up'):
         logger.debug(f'{__PLUGIN_NAME}up文件夹不存在')
         os.makedirs(baseDir + 'up')
-    else:
-        logger.debug(f'{__PLUGIN_NAME}up文件夹存在')
         
     if not os.path.exists(baseDir + 'user'):
         logger.debug(f'{__PLUGIN_NAME}user文件夹不存在')
         os.makedirs(baseDir + 'user')
-    else:
-        logger.debug(f'{__PLUGIN_NAME}user文件夹存在')
+    
+    if not os.path.exists(baseDir + 'group'):
+        logger.debug(f'{__PLUGIN_NAME}group文件夹不存在')
+        os.makedirs(baseDir + 'group')
+
